@@ -39,7 +39,7 @@ class FeaturesClient(NamespacedClient):
         Gets a list of features which can be included in snapshots using the feature_states
         field when creating a snapshot
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/get-features-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.1/get-features-api.html>`_
         """
         __path = "/_features"
         __query: t.Dict[str, t.Any] = {}
@@ -70,7 +70,7 @@ class FeaturesClient(NamespacedClient):
         """
         Resets the internal state of features, usually by deleting system indices
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-snapshots.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.1/modules-snapshots.html>`_
         """
         __path = "/_features/_reset"
         __query: t.Dict[str, t.Any] = {}
